@@ -789,7 +789,7 @@ class scoreUI:
 			if i == 0: 
 				maintimes = self.obj.input[0].preferences[0]
 				self.p.length = \
-					maintimes[0] * (int(self.p.length / maintimes[0]) + 1)
+					maintimes[0] * (int(self.p.length / maintimes[0]))
 			makeObjVoice(self.obj.input[i], self.p.length, maintimes)
 			self.score.AppendVoice(self.obj.input[i].voice)	
 		self.score.SetLength(self.p.length)
